@@ -33,8 +33,8 @@ class Modal(hg.DIV):
         if buttons and "data_modal_primary_focus" not in buttons[-1].attributes:
             buttons[-1].attributes["data_modal_primary_focus"] = True
         attributes["_class"] = attributes.get("_class", "") + " bx--modal"
-        self.id = id or hg.html_id(self, prefix="modal-")
-        self.openerattributes = {"data_modal_target": f"#{self.id}"}
+        self.id = hg.html_id(self, prefix="modal-") if id is None else id
+        self.openerattributes = {"data_modal_target": hg.format("#{}", self.id)}
         self.contentcontainer = hg.DIV(
             *content, _class="bx--modal-content", tabindex="0"
         )
@@ -94,7 +94,7 @@ class Modal(hg.DIV):
         """
         buttons = (Button(_("Cancel"), buttontype="ghost", data_modal_close=True),)
         if submitlabel:
-            buttons += (Button(submitlabel, type="submit", form=""),)
+            buttons += (Button(submitlabel, type="submit"),)
 
         modal = cls(
             heading,
@@ -107,9 +107,21 @@ class Modal(hg.DIV):
         )
         if submitlabel:
             buttons[1].attributes["hx_post"] = url
-            buttons[1].attributes["hx_target"] = f"#{modal.id} .bx--modal-content"
-            buttons[1].attributes["hx_include"] = f"#{modal.id} .bx--modal-content"
+            buttons[1].attributes["hx_target"] = hg.format(
+                "#{} .bx--modal-content", modal.id
+            )
+            buttons[1].attributes["hx_include"] = hg.format(
+                "#{} .bx--modal-content", modal.id
+            )
 
         modal.openerattributes["hx_get"] = url
-        modal.openerattributes["hx_target"] = f"#{modal.id} .bx--modal-content"
+        modal.openerattributes["hx_target"] = hg.format(
+            "#{} .bx--modal-content", modal.id
+        )
         return modal
+
+
+def modal_with_trigger(modal: Modal, triggerclass: hg.HTMLElement, *args, **kwargs):
+    return hg.BaseElement(
+        triggerclass(*args, **{**kwargs, **modal.openerattributes}), modal
+    )
